@@ -1,6 +1,6 @@
 #ifndef AUTO_CRON_H
 #define AUTO_CRON_H
 
-extern char auto_cron[];
+extern const char auto_cron[];
 
 #endif
