@@ -4,11 +4,14 @@
 /* The following substitutions are also made. If not set, ?????    */
 /* will be printed:                                                */
 /*   <#A#> target email address (<#a#>@<#h#>)                      */
+/*   <#C#> The confirm cookie hash code                            */
 /*   <#H#> outhost                                                 */
 /*   <#L#> outlocal (unchanged)                                    */
 /*   <#R#> confirm address (<#r#>@<#h#>)                           */
+/*   <#T#> confirm time stamp                                      */
+/*   <#X#> confirm action code                                     */
 /*   <#a#> local part of the target address                        */
-/*   <#c#> the confirm cookie                                      */
+/*   <#c#> the confirm cookie (<#X#>c.<#T#>.<#C#>-<#a#>=<#h#>)     */
 /*   <#d#> base directory name                                     */
 /*   <#h#> outhost                                                 */
 /*   <#l#> outlocal (modified for digest requests)                 */
@@ -40,11 +43,14 @@
 #include "mime.h"
 #include "altpath.h"
 #include "byte.h"
+#include "cookie.h"
+#include "datetime.h"
 #include "die.h"
+#include "fmt.h"
 #include "idx.h"
 #include "config.h"
 
-static stralloc line = {0};
+static stralloc srcline = {0};
 static stralloc outline = {0};
 static stralloc qline = {0};
 static substdio sstext;
@@ -53,6 +59,9 @@ static const char *target = "?????";
 static unsigned int targetlocal;
 static const char *verptarget = "?????";
 static const char *confirm = "?????";
+static const char *action = "??.";
+static char hash[COOKIE] = "????????????????????";
+static datetime_sec when = (datetime_sec)-1;
 static unsigned int confirmlocal;
 static unsigned int confirmprefix;
 static const char *szmsgnum = "?????";
@@ -80,6 +89,21 @@ void set_cpnum(const char *cf)
   szmsgnum = cf;
 }
 
+void set_cpaction(const char *ac)
+{
+  action = ac;
+}
+
+void set_cpwhen(datetime_sec t)
+{
+  when = t;
+}
+
+void set_cphash(const char h[COOKIE])
+{
+  byte_copy(hash,COOKIE,h);
+}
+
 void codeput(struct qmail *qq,const char *l,unsigned int n,char code)
 {
   if (!code || code == 'H')
@@ -110,6 +134,7 @@ void copy_xlate(stralloc *out,
 {
   unsigned int pos;
   unsigned int nextpos;
+  char strnum[FMT_ULONG];
 
   pos = 0;
   nextpos = 0;
@@ -127,13 +152,22 @@ void copy_xlate(stralloc *out,
 	if (q == 'H') strerr_die1x(111,MSG(ERR_SUBST_UNSAFE));
 	if (!stralloc_cats(out,target)) die_nomem();
 	break;
+      case 'C':
+	if (!stralloc_catb(out,hash,COOKIE)) die_nomem();
+	break;
       case 'L':
-	if (!quote(&qline,&local)) die_nomem();
+	if (!quote(&qline,&mainlocal)) die_nomem();
 	if (!stralloc_cat(out,&qline)) die_nomem();
 	break;
       case 'R':
 	if (!stralloc_cats(out,confirm)) die_nomem();
 	break;
+      case 'T':
+	if (!stralloc_catb(out,strnum,fmt_ulong(strnum,(unsigned long )when))) die_nomem();
+	break;
+      case 'X':
+	if (!stralloc_cats(out,action)) die_nomem();
+	break;
       case 'a':
 	if (!stralloc_catb(out,target,targetlocal)) die_nomem();
 	break;
@@ -205,20 +239,20 @@ void copy(struct qmail *qq,
 		   FATAL,MSG1(ERR_OPEN,fn));
   substdio_fdbuf(&sstext,read,fd,textbuf,sizeof(textbuf));
   for (;;) {
-    if (getln(&sstext,&line,&match,'\n') == -1)
+    if (getln(&sstext,&srcline,&match,'\n') == -1)
       strerr_die2sys(111,FATAL,MSG1(ERR_READ,fn));
-    if (line.len > 0) {		/* line.len is always > 0 if match is true */
-      if (line.s[0] == '#') continue;
+    if (srcline.len > 0) {		/* srcline.len is always > 0 if match is true */
+      if (srcline.s[0] == '#') continue;
       /* suppress blank line for 'H'eader mode */
-      if (line.len == 1 && q == 'H') continue;
-      if (line.s[0] == '!') {
-	if (line.s[1] == 'R') {
+      if (srcline.len == 1 && q == 'H') continue;
+      if (srcline.s[0] == '!') {
+	if (srcline.s[1] == 'R') {
 	  codeput(qq,"   ",3,q);
 	  codeputs(qq,confirm,q);
 	  codeput(qq,"\n",1,q);
 	  continue;
 	}
-	if (line.s[1] == 'A') {
+	if (srcline.s[1] == 'A') {
 	  codeput(qq,"   ",3,q);
 	  codeputs(qq,target,q);
 	  codeput(qq,"\n",1,q);
@@ -227,20 +261,20 @@ void copy(struct qmail *qq,
       }
       /* Find <=flags=> tags */
       if (q != 'H'
-	  && line.len >= 5
-	  && line.s[0] == '<'
-	  && line.s[1] == '='
-	  && line.s[line.len-3] == '='
-	  && line.s[line.len-2] == '>') {
+	  && srcline.len >= 5
+	  && srcline.s[0] == '<'
+	  && srcline.s[1] == '='
+	  && srcline.s[srcline.len-3] == '='
+	  && srcline.s[srcline.len-2] == '>') {
 	for (flagsmatched = 1, pos = 2;
-	     flagsmatched && pos < line.len - 3;
+	     flagsmatched && pos < srcline.len - 3;
 	     ++pos)
-	  flagsmatched = flagsmatched && flag_isset(line.s[pos]);
+	  flagsmatched = flagsmatched && flag_isset(srcline.s[pos]);
 	continue;
       }
       if (!flagsmatched) continue;
 
-      copy_xlate(&outline,&line,0,q);
+      copy_xlate(&outline,&srcline,0,q);
       codeput(qq,outline.s,outline.len,q);
 
       /* Last line is missing its trailing newline, add one on output. */
