@@ -1,39 +1,26 @@
-/* $Id: encodeQ.c,v 1.2 1998/02/28 19:03:02 lindberg Exp $*/
-/* $Name: ezmlm-idx-040 $*/
-
-#include "errtxt.h"
+#include "messages.h"
 #include "mime.h"
 #include "stralloc.h"
 #include "strerr.h"
+#include "die.h"
+#include "idx.h"
 
-static void die_nomem(fatal)
-  char *fatal;
-{
-  strerr_die2x(111,fatal,ERR_NOMEM);
-}
-
-static char *hexchar = "0123456789ABCDEF";
-
-void encodeQ(indata,n,outdata,fatal)
-char *indata;
-unsigned int n;
-stralloc *outdata;
-char *fatal;
+static const char hexchar[16] = "0123456789ABCDEF";
 
+void encodeQ(const char *indata,unsigned int n,stralloc *outdata)
 	/* converts any character with the high order bit set to */
 	/* quoted printable. In: n chars of indata, out: stralloc outdata*/
-
 {
-  register char *cpout;
-  register char ch;
+  char *cpout;
+  char ch;
   unsigned int i;
-  char *cpin;
+  const char *cpin;
 
   cpin = indata;
   i = 0;
 	/* max 3 outchars per inchar  & 2 char newline per 72 chars */
-  if (!stralloc_copys(outdata,"")) die_nomem(fatal);
-  if (!stralloc_ready(outdata,n * 3 + n/36)) die_nomem(fatal);	/* worst case */
+  if (!stralloc_copys(outdata,"")) die_nomem();
+  if (!stralloc_ready(outdata,n * 3 + n/36)) die_nomem();	/* worst case */
   cpout = outdata->s;
   while (n--) {
     ch = *cpin++;
