@@ -3,6 +3,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include "alloc.h"
+#include "byte.h"
 #include "error.h"
 #include "stralloc.h"
 #include "str.h"
@@ -34,7 +35,7 @@ const char WARNING[] = "ezmlm-archive: warning: inconsistent index: ";
 static int flagcreate = 0;
 static unsigned long archnum = 0L;
 static int flagsyncall = 0;
-static unsigned long to = 0L;
+static unsigned long optto = 0L;
 
 static struct option options[] = {
   OPT_FLAG(flagcreate,'c',1,0),
@@ -43,8 +44,8 @@ static struct option options[] = {
   OPT_ULONG_FLAG(archnum,'F',0,0),
   OPT_FLAG(flagsyncall,'s',1,0),
   OPT_FLAG(flagsyncall,'S',0,0),
-  OPT_ULONG(to,'t',0),
-  OPT_ULONG_FLAG(to,'T',0,0),
+  OPT_ULONG(optto,'t',0),
+  OPT_ULONG_FLAG(optto,'T',0,0),
   OPT_END
 };
 
@@ -91,12 +92,12 @@ void write_threads(const msgentry *msgtable,
 /* Writes the subject index first, then processes the individual files */
 {
   const msgentry *pmsgt;
-  subentry *psubt,*psubtm, *psubtlast;
+  subentry *psubt,*psubtm;
   subentry *presubt = (subentry *)0;
   const authentry *pautht;
   const dateentry *pdatet;
   const char *cp;
-  const char *cp1;
+  unsigned int cp1;
   unsigned long msg;
   unsigned long ulmsginthread;
   unsigned long subnum;
@@ -122,7 +123,6 @@ void write_threads(const msgentry *msgtable,
 	presubt = psubtm;	/* this thread extends beyond current month */
     if (psubtm->firstmsg >= nextmsg) {	/* done with this month */
       if (fdn != -1) close_proper(&ssout,fn.s,fnn.s);
-      psubtlast = psubtm;		/* last thread done */
       if (presubt)			/* need to rewind? */
 	psubtm = presubt;		/* do it */
       psubt = psubtm;			/* tmp pointer to reset done flag */
@@ -237,7 +237,7 @@ void write_threads(const msgentry *msgtable,
     if ((fd = open_read(fn.s)) == -1) {
       if (errno != error_noent)
 	  strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,fn.s));
-      if (substdio_puts(&ssout,psubt->sub) == -1)	/* write subject */
+      if (substdio_put(&ssout,psubt->sub,psubt->sublen) == -1)	/* write subject */
 	     strerr_die2sys(111,FATAL,MSG1(ERR_WRITE,fnn.s));
     } else {					/* copy data */
 	substdio_fdbuf(&ssin,read,fd,inbuf,sizeof(inbuf));
@@ -273,11 +273,10 @@ void write_threads(const msgentry *msgtable,
 	if (!stralloc_cats(&line,":")) die_nomem();
         if (pmsgt->authnum) {
 	  pautht = authtable + pmsgt->authnum - 1;
-	  cp = pautht->auth;
-	  cp1 = cp + str_chr(cp,' ');
-	  if (cp + HASHLEN != cp1)
+	  cp1 = byte_chr(pautht->auth,pautht->authlen,' ');
+	  if (cp1 != HASHLEN)
 	    strerr_die1x(100,MSG(ERR_BAD_INDEX));
-	  if (!stralloc_cats(&line,cp))
+	  if (!stralloc_catb(&line,pautht->auth,pautht->authlen))
 		die_nomem();				/* hash */
 	} else
           if (!stralloc_cats(&line,"\n")) die_nomem();
@@ -391,7 +390,7 @@ int main(int argc,char **argv)
     strerr_die1x(100,MSG(ERR_EMPTY_LIST));
   (void) close(fdlock);
 
-  if (!to || to > max) to = max;
+  if (!optto || optto > max) optto = max;
 
   fdlock = lockfile("archive/lock");	/* lock index */
   if (!flagcreate && !archnum) {	/* adjust archnum (from) / to */
@@ -401,7 +400,7 @@ int main(int argc,char **argv)
       archnum = 0;
   }
 
-  if (archnum > to)
+  if (archnum > optto)
     _exit(0);				/* nothing to do */
 
   if (mkdir("archive/threads",0755) == -1)
@@ -415,14 +414,14 @@ int main(int argc,char **argv)
       strerr_die2sys(111,FATAL,MSG1(ERR_CREATE,"archive/authors"));
 
 					/* do the subject threading */
-  idx_mkthreads(&msgtable,&subtable,&authtable,&datetable,archnum,to,max,0);
+  idx_mkthreads(&msgtable,&subtable,&authtable,&datetable,archnum,optto,max,0);
 					/* update the index */
-  write_threads(msgtable,subtable,authtable,datetable,archnum,to);
+  write_threads(msgtable,subtable,authtable,datetable,archnum,optto);
 					/* update archnum */
   if ((fd = open_trunc("archnumn")) == -1)
     strerr_die2sys(111,FATAL,MSG1(ERR_CREATE,"archnumn"));
   substdio_fdbuf(&ssnum,write,fd,numbuf,sizeof(numbuf));
-  if (substdio_put(&ssnum,strnum,fmt_ulong(strnum,to)) == -1)
+  if (substdio_put(&ssnum,strnum,fmt_ulong(strnum,optto)) == -1)
      strerr_die2sys(111,FATAL,MSG1(ERR_WRITE,fnn.s));
   if (substdio_puts(&ssnum,"\n") == -1)
      strerr_die2sys(111,FATAL,MSG1(ERR_WRITE,fnn.s));
