@@ -135,7 +135,7 @@ static int fd;		/* same; never >1 open */
 static int cache;	/* 0 = don't; 1 = don't know; 2 = do */
 static int flagtoplevel;
 static unsigned int flagmime;
-static unsigned int cs,csbase,pos;
+static unsigned int cs,csbase;
 static int flagrobot;
 static int flagpre;
 static int precharcount;
@@ -945,7 +945,7 @@ void indexlinks(struct msginfo *infop)
 int show_index(struct msginfo *infop)
 {
   unsigned long thismsg;
-  unsigned int pos,l;
+  unsigned int pos;
   char ch;
 
   (void) makefn(&fn,ITEM_INDEX,msginfo.target,"");
@@ -973,7 +973,6 @@ int show_index(struct msginfo *infop)
     if (!match)
       break;
     pos = scan_ulong(line.s,&thismsg);
-    l = pos;
     ch = line.s[pos++];
     pos++;
     if (line.len < pos + 1 + HASHLEN)
@@ -1215,11 +1214,11 @@ void mime_getarg(stralloc *sa,char **s, unsigned int *l)
       return;
 }
 
-void decode_mime_type(char *s,unsigned int l,unsigned int flagmime)
+void decode_mime_type(char *s,unsigned int l,unsigned int domime)
 {
   char *st;
   unsigned int r,lt;
-  if (!flagmime || !l) {		/* treat non-MIME as plain text */
+  if (!domime || !l) {		/* treat non-MIME as plain text */
     mime_current->mimetype = MIME_TEXT_PLAIN;
     if (!stralloc_copys(&curcharset,charset)) die_nomem();
 	/* should be us-ascii, but this is very likely better */
@@ -1378,14 +1377,12 @@ void show_part(struct msginfo *infop,int flagshowheaders,int flagstartseen)
 /* if not we'll ignore what's there up to it */
 /* if flagskip we skip this part */
 {
-  char *cp;
   int flaginheader;
   int whatheader;
   int flaggoodfield;
   int flaghtml;
   int btype,i;
   unsigned int colpos;
-  char linetype;
 
   flaginheader = 1;
   for (i = 0; i < NO_HDRS; i++) hdr[i].len = 0;
@@ -1445,10 +1442,8 @@ void show_part(struct msginfo *infop,int flagshowheaders,int flagstartseen)
 	      oputs("\">");
 	    }
 	    if (flagobscure && i == HDR_FROM - 1) {
-	      int k;
 	      oputs(" ");
-	      k = author_name(&cp,line.s,line.len);
-	      decodeHDR(cp,k,&decline);
+	      author_name(&decline,line.s,line.len);
 	      html_put(decline.s,decline.len);
 	    } else {
 	      decodeHDR(hdr[i].s,hdr[i].len,&decline);
@@ -1512,7 +1507,6 @@ void show_part(struct msginfo *infop,int flagshowheaders,int flagstartseen)
 		continue;
 	}
       } else if (line.s[0] != ' ' && line.s[0] != '\t') {
-	linetype = ' ';
         flaggoodfield = 0;
 	colpos = byte_chr(line.s,line.len,':');
 	if ((whatheader = constmap_index(&headermap,line.s,colpos))) {
@@ -1726,6 +1720,7 @@ void setmsg(struct msginfo *infop)
 /* first thread in the date file. DIRECT_LAST is not supported.        */
 /* DIRECT_FIRST is supported ONLY for date. */
 {
+  unsigned int pos;
   if (infop->direction == DIRECT_SAME) {
     infop->target = infop->source;
     return;
