@@ -42,18 +42,18 @@
 #include "config.h"
 #include "auto_version.h"
 
-int flagdo = 1;			/* React to commands (doesn't affect -dig)*/
-int omitbottom = 0;		/* copy text/bottom + request */
-int flagpublic = -1;		/* 0 = non-public, 1 = public, -1 = respect */
-				/* dir/public. */
-int flagsubonly = -1;		/* =1 subscribers only for get/index/thread */
-unsigned long copylines = 0;	/* Number of lines from the message to copy */
-const char *digsz =
+static int flagdo = 1;			/* React to commands (doesn't affect -dig)*/
+static int omitbottom = 0;		/* copy text/bottom + request */
+static int flagpublic = -1;		/* 0 = non-public, 1 = public, -1 = respect */
+					/* dir/public. */
+static int flagsubonly = -1;		/* =1 subscribers only for get/index/thread */
+static unsigned long copylines = 0;	/* Number of lines from the message to copy */
+static const char *digsz =
 		"from\\to\\subject\\reply-to\\date\\message-id\\cc\\"
 		"mime-version\\content-type\\content-transfer-encoding";
-int flagarchived;		/* if list is archived */
-int flagindexed;		/* if list is indexed */
-const char *flagformat = 0;
+static int flagarchived;		/* if list is archived */
+static int flagindexed;		/* if list is indexed */
+static const char *flagformat = 0;
 
 const char FATAL[] = "ezmlm-get: fatal: ";
 const char USAGE[] =
@@ -75,64 +75,58 @@ static struct option options[] = {
   OPT_END
 };
 
-stralloc listname = {0};
-stralloc fn = {0};
-stralloc moddir = {0};
-stralloc mydtline = {0};
-stralloc digheaders = {0};
-stralloc seed = {0};
-stralloc digestcodefile = {0};
-struct constmap digheadersmap;
+static stralloc listname = {0};
+static stralloc filename = {0};
+static stralloc moddir = {0};
+static stralloc mydtline = {0};
+static stralloc digheaders = {0};
+static stralloc seed = {0};
+static stralloc digestcodefile = {0};
+static struct constmap digheadersmap;
 
-char schar[] = "00_";
-stralloc listno = {0};
+static char schar[] = "00_";
 
-datetime_sec when;
-unsigned long cumsize = 0L;	/* cumulative msgs / 256 */
-unsigned long cumsizen = 0L;	/* new cumulative msgs / 256 */
-unsigned long max = 0L;		/* Last message in archive */
-unsigned long msgsize = 0L;	/* for digest accounting */
-datetime_sec digwhen;		/* last digest */
+static datetime_sec when;
+static unsigned long cumsize = 0L;	/* cumulative msgs / 256 */
+static unsigned long cumsizen = 0L;	/* new cumulative msgs / 256 */
+static unsigned long max = 0L;		/* Last message in archive */
+static unsigned long msgsize = 0L;	/* for digest accounting */
+static datetime_sec digwhen;		/* last digest */
 
-char strnum[FMT_ULONG];
-char strnum2[FMT_ULONG];
-char szmsgnum[FMT_ULONG];
+static char strnum[FMT_ULONG];
+static char strnum2[FMT_ULONG];
+static char szmsgnum[FMT_ULONG];
 char boundary[COOKIE];
-char hashout[COOKIE];
+static char hashout[COOKIE];
 stralloc line = {0};
-stralloc line2 = {0};
-stralloc qline = {0};
+static stralloc line2 = {0};
+static stralloc qline = {0};
 stralloc quoted = {0};
-stralloc msgnum = {0};
-stralloc num = {0};
-stralloc subject = {0};
-stralloc author = {0};
+static stralloc author = {0};
 
 /* for copy archive */
-stralloc archdate = {0};
-stralloc archfrom = {0};
-stralloc archto = {0};
-stralloc archcc = {0};
-stralloc archsubject = {0};
-stralloc archmessageid = {0};
-stralloc archkeywords = {0};
-stralloc archblanklines = {0};
-char archtype=' ';
+static stralloc archdate = {0};
+static stralloc archfrom = {0};
+static stralloc archto = {0};
+static stralloc archcc = {0};
+static stralloc archsubject = {0};
+static stralloc archmessageid = {0};
+static stralloc archkeywords = {0};
+static stralloc archblanklines = {0};
 
 /* for mods on non-public lists (needed for future fuzzy sub dbs) */
-stralloc mod = {0};		/* moderator addr for non-public lists */
-int ismod = 0;			/* true for moderator senders */
+static stralloc mod = {0};		/* moderator addr for non-public lists */
+static int ismod = 0;			/* true for moderator senders */
 
-int act = AC_NONE;		/* Action we do */
-int flageditor = 0;		/* if we're invoked for within dir/editor */
-struct stat st;
+static int act = AC_NONE;		/* Action we do */
+static int flageditor = 0;		/* if we're invoked for within dir/editor */
+static struct stat st;
 
-int flaglocked = 0;		/* if directory is locked */
-int flagq = 0;			/* don't use 'quoted-printable' */
+static int flaglocked = 0;		/* if directory is locked */
 
-const char *workdir;
-const char *sender;
-const char *digestcode;
+static const char *workdir;
+static const char *sender;
+static const char *digestcode;
 
 struct qmail qq;
 
@@ -144,22 +138,19 @@ int subto(const char *s,unsigned int l)
   return (int) l;
 }
 
-char inbuf[1024];
-substdio ssin = SUBSTDIO_FDBUF(read,0,inbuf,sizeof(inbuf));
-substdio ssin2 = SUBSTDIO_FDBUF(read,0,inbuf,sizeof(inbuf));
+static char inbuf[1024];
+static substdio ssin = SUBSTDIO_FDBUF(read,0,inbuf,sizeof(inbuf));
+static substdio ssin2 = SUBSTDIO_FDBUF(read,0,inbuf,sizeof(inbuf));
 
-substdio ssnum;
-char numbuf[16];
+static substdio ssnum;
+static char numbuf[16];
 
-substdio sstext;
-char textbuf[1024];
+static substdio sstext;
+static char textbuf[1024];
 
-substdio ssindex;
-char indexbuf[1024];
+static int fdlock;
 
-int fdlock;
-
-void lockup(void)
+static void lockup(void)
 /* lock unless locked */
 {
   if(!flaglocked) {
@@ -168,7 +159,7 @@ void lockup(void)
   }
 }
 
-void unlock(void)
+static void unlock(void)
 /* unlock if locked */
 {
   if (flaglocked) {
@@ -177,7 +168,7 @@ void unlock(void)
   }
 }
 
-void code_qput(const char *s,unsigned int n)
+static void code_qput(const char *s,unsigned int n)
 {
     if (!flagcd)
       qmail_put(&qq,s,n);
@@ -191,7 +182,7 @@ void code_qput(const char *s,unsigned int n)
     }
 }
 
-void code_qputs(const char *s)
+static void code_qputs(const char *s)
 {
   code_qput(s,str_len(s));
   code_qput("\n",1);
@@ -223,13 +214,13 @@ void tosender(void)
   qmail_puts(&qq,"\n");
 }
 
-void get_num(void)
+static void get_num(void)
 {
   /* read dir/num -> max. */
   getconf_ulong2(&max,&cumsizen,"num",0);
 }
 
-unsigned long dignum(void)
+static unsigned long dignum(void)
 {
 /* return dignum if exists, 0 otherwise. */
   unsigned long u;
@@ -379,12 +370,11 @@ void copymsg(int fd,char format)
   int match;
   int flaginheader;
   int flagskipblanks;
-  int flaggoodfield;
 
+  substdio_fdbuf(&sstext,read,fd,textbuf,sizeof(textbuf));
   switch(format) {
     case VIRGIN:
     case NATIVE:
-      substdio_fdbuf(&sstext,read,fd,textbuf,sizeof(textbuf));
       for (;;) {
         if (getln(&sstext,&line,&match,'\n') == -1)
            strerr_die2sys(111,FATAL,MSG1(ERR_READ,line.s));
@@ -398,25 +388,19 @@ void copymsg(int fd,char format)
     case MIME:
     case MIXED:
       flaginheader = 1;
-      flaggoodfield = 0;
-      substdio_fdbuf(&sstext,read,fd,textbuf,sizeof(textbuf));
       for (;;) {
-        if (getln(&sstext,&line,&match,'\n') == -1)
+        if (gethdrln(&sstext,&line,&match,'\n') == -1)
            strerr_die2sys(111,FATAL,MSG1(ERR_READ,line.s));
         if (match) {
           if (flaginheader) {
             if (line.len == 1) {
               flaginheader = 0;
-              flaggoodfield = 1;
-            } else if (line.s[0] != ' ' && line.s[0] != '\t') {
-              flaggoodfield = 0;
+            } else {
               if (constmap(&digheadersmap,line.s,
-			byte_chr(line.s,line.len,':')))
-                flaggoodfield = 1;
-            }
-            if (flaggoodfield) {
-              qmail_put(&qq,line.s,line.len);		/* header */
-	      msgsize += line.len;
+			   byte_chr(line.s,line.len,':'))) {
+		qmail_put(&qq,line.s,line.len);		/* header */
+		msgsize += line.len;
+	      }
 	    }
           } else {
             qmail_put(&qq,line.s,line.len);		/* body */
@@ -429,16 +413,15 @@ void copymsg(int fd,char format)
     case RFC1153:		/* Not worth optimizing. Rarely used */
       flaginheader = 1;
       flagskipblanks = 1;	/* must skip terminal blanks acc to rfc1153 */
-      archtype = ' ';		/* rfc1153 requires ordered headers */
       if (!stralloc_copys(&archblanklines,"")) die_nomem();
-      substdio_fdbuf(&sstext,read,fd,textbuf,sizeof(textbuf));
       for (;;) {
-        if (getln(&sstext,&line,&match,'\n') == -1)
+        if (gethdrln(&sstext,&line,&match,'\n') == -1)
            strerr_die2sys(111,FATAL,MSG1(ERR_READ,line.s));
         if (match) {
           if (flaginheader) {
             if (line.len == 1) {
               flaginheader = 0;
+	      /* rfc1153 requires ordered headers */
               if (archdate.len) {
                 qmail_put(&qq,archdate.s,archdate.len);
                 archdate.len = 0;
@@ -475,56 +458,26 @@ void copymsg(int fd,char format)
                 archkeywords.len = 0;
               }
               qmail_puts(&qq,"\n");
-            } else if (line.s[0] == ' ' || line.s[0] == '\t') {
-              switch (archtype) {	/* continuation lines */
-                case ' ':
-                  break;
-                case 'D':
-                  if (!stralloc_cat(&archdate,&line)) die_nomem(); break;
-                case 'F':
-                  if (!stralloc_cat(&archfrom,&line)) die_nomem(); break;
-                case 'T':
-                  if (!stralloc_cat(&archto,&line)) die_nomem(); break;
-                case 'C':
-                  if (!stralloc_cat(&archcc,&line)) die_nomem(); break;
-                case 'S':
-                  if (!stralloc_cat(&archsubject,&line)) die_nomem(); break;
-                case 'M':
-                  if (!stralloc_cat(&archmessageid,&line)) die_nomem(); break;
-                case 'K':
-                  if (!stralloc_cat(&archkeywords,&line)) die_nomem(); break;
-                default:
-                  strerr_die2x(111,FATAL,
-                      "Program error: Bad archive header type");
-              }
             } else {
-              archtype = ' ';
               if (case_startb(line.s,line.len,"cc:")) {
-                archtype='C';
                 if (!stralloc_copy(&archcc,&line)) die_nomem();
               }
               else if (case_startb(line.s,line.len,"date:")) {
-                archtype='D';
                 if (!stralloc_copy(&archdate,&line)) die_nomem();
               }
               else if (case_startb(line.s,line.len,"from:")) {
-                archtype='F';
                 if (!stralloc_copy(&archfrom,&line)) die_nomem();
               }
               else if (case_startb(line.s,line.len,"keywords:")) {
-                archtype='K';
                 if (!stralloc_copy(&archkeywords,&line)) die_nomem();
               }
               else if (case_startb(line.s,line.len,"message-id:")) {
-                archtype='M';
                 if (!stralloc_copy(&archmessageid,&line)) die_nomem();
               }
               else if (case_startb(line.s,line.len,"subject:")) {
-                archtype='S';
                 if (!stralloc_copy(&archsubject,&line)) die_nomem();
               }
               else if (case_startb(line.s,line.len,"to:")) {
-                archtype='T';
                 if (!stralloc_copy(&archto,&line)) die_nomem();
               }
             }
@@ -569,24 +522,24 @@ void msgout(unsigned long msg,char format)
   int fd;
   unsigned int len;
 
-    if (!stralloc_copys(&fn,"archive/")) die_nomem();
+    if (!stralloc_copys(&filename,"archive/")) die_nomem();
 
     len = fmt_ulong(strnum, msg / 100);
-    if (!stralloc_catb(&fn,strnum,len)) die_nomem();
-    if (!stralloc_cats(&fn,"/")) die_nomem();
+    if (!stralloc_catb(&filename,strnum,len)) die_nomem();
+    if (!stralloc_cats(&filename,"/")) die_nomem();
     len = fmt_uint0(strnum, (unsigned int) (msg % 100),2);
-    if (!stralloc_catb(&fn,strnum,len)) die_nomem();
-    if (!stralloc_0(&fn)) die_nomem();
+    if (!stralloc_catb(&filename,strnum,len)) die_nomem();
+    if (!stralloc_0(&filename)) die_nomem();
 
     switch(format) {
       case MIME:
       case VIRGIN:
       case NATIVE:
       case MIXED:
-	fd = open_read(fn.s);
+	fd = open_read(filename.s);
 	if (fd == -1) {
 	  if (errno != error_noent)
-	    strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,fn.s));
+	    strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,filename.s));
           else
             mime_getbad(msg);
         } else if (fstat(fd,&st) == -1 || (!(st.st_mode & 0100))) {
@@ -605,10 +558,10 @@ void msgout(unsigned long msg,char format)
         }
 	break;
       case RFC1153:
-	fd = open_read(fn.s);
+	fd = open_read(filename.s);
 	if (fd == -1) {
 	  if (errno != error_noent)
-	    strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,fn.s));
+	    strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,filename.s));
 	  else {
 	    qmail_puts(&qq,"\n== ");
 	    qmail_put(&qq,strnum,fmt_ulong(strnum,msg));
@@ -674,7 +627,7 @@ void digest(msgentry *msgtable,
             if (!stralloc_copys(&line,"")) die_nomem();
           if (!stralloc_cats(&line,"\t")) die_nomem();
           if (!stralloc_catb(&line,strnum,fmt_ulong(strnum,msg))) die_nomem();
-          if (!stralloc_append(&line," ")) die_nomem();
+          if (!stralloc_append(&line,' ')) die_nomem();
           if (pmsgt->authnum) {
 	    author.len = 0;
 	    cp = authtable[pmsgt->authnum - 1].auth;
@@ -687,7 +640,7 @@ void digest(msgentry *msgtable,
 	    if (!stralloc_0(&author)) die_nomem();
 	  }
           if (!stralloc_cats(&line,MSG1(TXT_BY,author.s))) die_nomem();
-	  if (!stralloc_append(&line,"\n")) die_nomem();
+	  if (!stralloc_append(&line,'\n')) die_nomem();
           code_qput(line.s,line.len);
         }
         pmsgt++;
@@ -735,11 +688,10 @@ void doheaders(void)
   flaggoodfield = 0;
   if (act != AC_DIGEST)
     for (;;) {
-    if (getln(&ssin,&line,&match,'\n') == -1)
+    if (gethdrln(&ssin,&line,&match,'\n') == -1)
       strerr_die2sys(111,FATAL,MSG(ERR_READ_INPUT));
     if (!match) break;
     if (line.len == 1) break;
-    if ((line.s[0] != ' ') && (line.s[0] != '\t')) {
       flaggoodfield = 0;
       if (case_startb(line.s,line.len,"mailing-list:")) {
         if (flageditor)			/* we may be running from a sublist */
@@ -754,7 +706,6 @@ void doheaders(void)
         flaggoodfield = 1;
       if (case_startb(line.s,line.len,"received:"))
         flaggoodfield = 1;
-    }
     if (flaggoodfield)
       qmail_put(&qq,line.s,line.len);
   }
@@ -788,6 +739,8 @@ int main(int argc,char **argv)
   dateentry *datetable;
   struct datetime dt;
   char date[DATE822FMT];
+  stralloc num = {0};
+  stralloc subject = {0};
 
   (void) umask(022);
   sig_pipeignore();
@@ -1127,25 +1080,25 @@ int main(int argc,char **argv)
     u /= 100;
     to /= 100;
     while (u <= to) {
-      if (!stralloc_copys(&fn,"archive/")) die_nomem();
-      if (!stralloc_catb(&fn,strnum,fmt_ulong(strnum,u))) die_nomem();
-      if (!stralloc_cats(&fn,"/index")) die_nomem();
-      if (!stralloc_0(&fn)) die_nomem();
+      if (!stralloc_copys(&filename,"archive/")) die_nomem();
+      if (!stralloc_catb(&filename,strnum,fmt_ulong(strnum,u))) die_nomem();
+      if (!stralloc_cats(&filename,"/index")) die_nomem();
+      if (!stralloc_0(&filename)) die_nomem();
 
       if (u == max/100)	/* lock if last index file in archive */
         lockup();
 
-      fd = open_read(fn.s);
+      fd = open_read(filename.s);
       if (fd == -1)
         if (errno != error_noent)
-          strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,fn.s));
+          strerr_die2sys(111,FATAL,MSG1(ERR_OPEN,filename.s));
         else
           code_qputs(MSG(TXT_NOINDEX));
       else {
         substdio_fdbuf(&sstext,read,fd,textbuf,sizeof(textbuf));
         for (;;) {
           if (getln(&sstext,&line,&match,'\n') == -1)
-            strerr_die2sys(111,FATAL,MSG1(ERR_READ,fn.s));
+            strerr_die2sys(111,FATAL,MSG1(ERR_READ,filename.s));
           if (match) {
             if (line.s[0] != '\t') {	/* subject line */
               pos = byte_chr(line.s,line.len,' ');
