@@ -47,42 +47,15 @@ static struct option options[] = {
   OPT_END
 };
 
-char strnum[FMT_ULONG];
-char hash[HASHLEN];
-
-stralloc fnadir = {0};
-stralloc fnif = {0};
-stralloc fnifn = {0};
-stralloc fnaf = {0};
-
-stralloc line = {0};
-stralloc lines = {0};
-stralloc dummy = {0};
-
-int fdindexn;
-int fdlock;
-int fd;
-
 	/* for reading index and in ezmlm-idx for reading message */
-static substdio ssin;
-static char inbuf[1024];
+static stralloc line = {0};
+static stralloc lines = {0};
+static stralloc subject = {0};
+static stralloc author = {0};
+static stralloc received = {0};
+static stralloc prefix = {0};
 
-substdio ssindex;
-char indexbuf[1024];
-
-struct stat st;
-
-stralloc subject = {0};
-stralloc author = {0};
-stralloc authmail = {0};
-stralloc received = {0};
-stralloc prefix = {0};
-
-struct strerr index_err;
-
-stralloc num = {0};
-
-int idx_get_trimsubject(void)
+static int idx_get_trimsubject(int fd)
 
 /* reads an open message from 'fd', extracts the subject (if any), and    */
 /* returns the subject in 'sub', the author in 'author', and the received */
@@ -94,47 +67,37 @@ int idx_get_trimsubject(void)
 /* No terminal '\n' in any of the strallocs! */
 {
 int foundsubject = 0;
-int issubject = 0;
-int isfrom = 0;
 int foundreceived = 0;
 int foundfrom = 0;
 int match;
 int r;
 unsigned int pos,pos1;
 
+  substdio ssin;
+  char inbuf[1024];
+
   substdio_fdbuf(&ssin,read,fd,inbuf,sizeof(inbuf));
   for (;;) {
-    if (getln(&ssin,&line,&match,'\n') == -1)
+    if (gethdrln(&ssin,&line,&match,'\n') == -1)
       strerr_die2x(111,FATAL,MSG(ERR_READ_INPUT));
     if (match) {
       if (line.len == 1)
         break;
-      if (*line.s == ' ' || *line.s == '\t') {
-				/* continuation */
-        if (issubject) {
-          if (!stralloc_cat(&subject,&line)) die_nomem();
-        } else if (isfrom)
-          if (!stralloc_cat(&author,&line)) die_nomem();
-      } else {
-        issubject = 0;
-        isfrom = 0;
-        if (!foundsubject && case_startb(line.s,line.len,"Subject:")) {
-          if (!stralloc_copyb(&subject,line.s+8,line.len-8)) die_nomem();
-          foundsubject = 1;
-          issubject = 1;
-        } else if (!foundfrom && case_startb(line.s,line.len,"From:")) {
-          if (!stralloc_copyb(&author,line.s+5,line.len-5)) die_nomem();
-          foundfrom = 1;
-          isfrom = 1;
-        } else if (!flagdate && !foundreceived &&
-            case_startb(line.s,line.len,"Received:")) {
+      if (!foundsubject && case_startb(line.s,line.len,"Subject:")) {
+	if (!stralloc_copyb(&subject,line.s+8,line.len-8)) die_nomem();
+	foundsubject = 1;
+      } else if (!foundfrom && case_startb(line.s,line.len,"From:")) {
+	if (!stralloc_copyb(&author,line.s+5,line.len-5)) die_nomem();
+	foundfrom = 1;
+      } else if (!flagdate && !foundreceived &&
+		 case_startb(line.s,line.len,"Received:")) {
           pos = byte_chr(line.s,line.len,';');
           if (pos != line.len)
             if (!stralloc_copyb(&received,line.s+pos+2,line.len - pos - 3))
               die_nomem();
           foundreceived = 1;
-        } else if (flagdate && !foundreceived &&
-            case_startb(line.s,line.len,"Date:")) {
+      } else if (flagdate && !foundreceived &&
+		 case_startb(line.s,line.len,"Date:")) {
           if (line.len < 22) continue;				/* illegal */
           pos = 6 + byte_chr(line.s+6,line.len-6,',');
           if (pos == line.len)
@@ -168,7 +131,6 @@ unsigned int pos,pos1;
             }
           }
           received.len = 0;		/* bad format - scrap */
-        }
       }
     } else
       break;
@@ -189,15 +151,31 @@ unsigned int pos,pos1;
 
 int main(int argc,char **argv)
 {
-  char *cp;
+  stralloc fnadir = {0};
+  stralloc fnif = {0};
+  stralloc fnifn = {0};
+  stralloc fnaf = {0};
+
+  stralloc dummy = {0};
+
+  int fdindexn = -1;
+
+  substdio ssindex;
+  char indexbuf[1024];
+
+  struct stat st;
+
+  char strnum[FMT_ULONG];
+  char hash[HASHLEN];
   int r;
+  int fd;
 
   getconfopt(argc,argv,options,1,0);
 
   (void) umask(022);
   sig_pipeignore();
 			/* obtain lock to write index files */
-  fdlock = lockfile("lock");
+  lockfile("lock");
 
   getconf_line(&prefix,"prefix",0);
 					/* support rfc2047-encoded prefix */
@@ -251,12 +229,10 @@ int main(int argc,char **argv)
     } else if (fstat(fd,&st) == -1 || (!(st.st_mode & 0100)))
         close(fd);
     else {
-      int k;
-
       subject.len = 0;		/* clear in case they're missing in msg */
       author.len = 0;
       received.len = 0;
-      r = idx_get_trimsubject();
+      r = idx_get_trimsubject(fd);
       close(fd);
       if (!stralloc_copyb(&line,strnum,fmt_ulong(strnum,msgnum))) die_nomem();
       if (!stralloc_cats(&line,": ")) die_nomem();
@@ -274,8 +250,7 @@ int main(int argc,char **argv)
       mkauthhash(lines.s,lines.len,hash);
       if (!stralloc_catb(&line,hash,HASHLEN)) die_nomem();
 
-      k = author_name(&cp,lines.s,lines.len);
-      decodeHDR(cp,k,&author);
+      author_name(&author,lines.s,lines.len);
 
       (void) unfoldHDR(author.s,author.len,&lines,charset.s,&prefix,0);
 
@@ -303,7 +278,6 @@ int main(int argc,char **argv)
   if (fd == -1)
     strerr_die2sys(100,FATAL,MSG1(ERR_CREATE,"indexed"));
   close(fd);
-  close(fdlock);
   _exit(0);
 }
 
