@@ -58,35 +58,17 @@ static struct option options[] = {
   OPT_END
 };
 
-stralloc mydtline = {0};
-stralloc accept = {0};
-stralloc reject = {0};
-stralloc to = {0};
-stralloc send = {0};
-stralloc comment = {0};
-datetime_sec when;
+static stralloc to = {0};
 
-char strnum[FMT_ULONG];
-char hash[COOKIE];
 char boundary[COOKIE];
 stralloc line = {0};
 stralloc qline = {0};
-stralloc text = {0};
 stralloc quoted = {0};
-stralloc fnbase = {0};
-stralloc fnmsg = {0};
-stralloc fnnew = {0};
-stralloc fnsub = {0};
-char subbuf[256];
-substdio sssub;
-
-static const char *dir;
-
-struct stat st;
+static stralloc fnmsg = {0};
 
 struct qmail qq;
 
-void code_qput(const char *s,unsigned int n)
+static void code_qput(const char *s,unsigned int n)
 {
     if (!flagcd)
       qmail_put(&qq,s,n);
@@ -99,7 +81,7 @@ void code_qput(const char *s,unsigned int n)
     }
 }
 
-int checkfile(const char *fn)
+static int checkfile(const char *fn)
 /* looks for DIR/mod/{pending|rejected|accept}/fn.*/
 /* Returns:                                       */
 /*          1 found in pending                    */
@@ -110,6 +92,7 @@ int checkfile(const char *fn)
 /* ALSO: if found, fnmsg contains the o-terminated*/
 /* file name.                                     */
 {
+  struct stat st;
   
   if (!stralloc_copys(&fnmsg,"mod/pending/")) die_nomem();
   if (!stralloc_cats(&fnmsg,fn)) die_nomem();
@@ -140,10 +123,7 @@ int checkfile(const char *fn)
   return 0;
 }
 
-substdio sstext;
-char textbuf[1024];
-
-void maketo(void)
+static void maketo(void)
 /* expects line to be a return-path line. If it is and the format is valid */
 /* to is set to to the sender. Otherwise, to is left untouched. Assuming   */
 /* to is empty to start with, it will remain empty if no sender is found.  */
@@ -169,10 +149,9 @@ int main(int argc,char **argv)
   char *local;
   const char *action;
   int flaginheader;
-  int flagcomment;
   int flaggoodfield;
   int flagdone;
-  int fd, fdlock;
+  int fd;
   int match;
   const char *err;
   char encin = '\0';
@@ -180,7 +159,16 @@ int main(int argc,char **argv)
   unsigned int pos,i;
   int child;
   int opt;
-  char *cp,*cpnext,*cpfirst,*cplast,*cpafter;
+  char *cp,*cpnext,*cplast,*cpafter;
+  char strnum[FMT_ULONG];
+  char hash[COOKIE];
+  substdio sstext;
+  char textbuf[1024];
+  datetime_sec when;
+  stralloc text = {0};
+  stralloc fnbase = {0};
+  stralloc fnnew = {0};
+  const char *dir;
 
   (void) umask(022);
   sig_pipeignore();
@@ -225,7 +213,7 @@ int main(int argc,char **argv)
   if (byte_diff(hash,COOKIE,action+confnum+1))
     die_badformat();
 
-  fdlock = lockfile("mod/lock");
+  lockfile("mod/lock");
 
   switch(checkfile(fnbase.s)) {
     case 0:
@@ -285,7 +273,6 @@ int main(int argc,char **argv)
     copy(&qq,"text/top",flagcd);
     copy(&qq,"text/mod-reject",flagcd);
 
-    flagcomment = 0;
     flaginheader = 1;
     if (!stralloc_copys(&text,"")) die_nomem();
     if (!stralloc_ready(&text,1024)) die_nomem(); 
@@ -329,7 +316,6 @@ int main(int argc,char **argv)
             if (!stralloc_copyb(&quoted,cp,i)) die_nomem();	/* quote chars*/
             flaggoodfield = 1;
             cp = cpnext + 1;
-            cpfirst = cp;
             continue;
           } else {						/* end tag */
             if (flagdone)	/* 0 no comment lines, 1 comment line */
