@@ -17,6 +17,7 @@
 #include "env.h"
 #include "sender.h"
 #include "messages.h"
+#include "mime.h"
 #include "die.h"
 #include "idx.h"
 #include "config.h"
@@ -26,22 +27,22 @@ const char FATAL[] = "ezmlm-reject: fatal: ";
 const char USAGE[] =
 "ezmlm-reject: usage: ezmlm-reject [-bBcCfFhHqQsStT] [dir]";
 
-int flagrejectcommands = 1;	/* reject if subject is simple command */
-int flagneedsubject = 1;	/* reject if subject is missing */
-int flagtook = 0;		/* reject unless listaddress in To: or Cc: */
-int exitquiet = 100;		/* reject with error (100) rather than exit */
-				/* quietly (99) if listaddress missing */
-int flagheaderreject = 1;	/* reject messages with headers listed in */
-				/* DIR/headerreject. */
-int flagbody = 0;		/* =1 => reject if subject or body starts with*/
-				/* "subscribe" or "unsubscribe" */
-int flagforward = 0;		/* =1 => forward commands to list-request */
-int flagparsemime = 0;
-int flaghavesubject = 0;
-int flaghavecommand = 0;
-int flagcheck = 0;		/* set after boundary is found in body, */
-				/* until blank line */
-unsigned long copylines = 0;	/* Number of lines from the message to copy */
+static int flagrejectcommands = 1;	/* reject if subject is simple command */
+static int flagneedsubject = 1;		/* reject if subject is missing */
+static int flagtook = 0;		/* reject unless listaddress in To: or Cc: */
+static int exitquiet = 100;		/* reject with error (100) rather than exit */
+					/* quietly (99) if listaddress missing */
+static int flagheaderreject = 1;	/* reject messages with headers listed in */
+					/* DIR/headerreject. */
+static int flagbody = 0;		/* =1 => reject if subject or body starts with*/
+					/* "subscribe" or "unsubscribe" */
+static int flagforward = 0;		/* =1 => forward commands to list-request */
+static int flagparsemime = 0;
+static int flaghavesubject = 0;
+static int flaghavecommand = 0;
+static int flagcheck = 0;		/* set after boundary is found in body, */
+					/* until blank line */
+static unsigned long copylines = 0;	/* Number of lines from the message to copy */
 
 static struct option options[] = {
   OPT_FLAG(flagbody,'b',1,0),
@@ -61,31 +62,26 @@ static struct option options[] = {
   OPT_END
 };
 
-stralloc mimeremove = {0};
-stralloc mimereject = {0};
-stralloc headerreject = {0};
+static stralloc mimeremove = {0};
+static stralloc mimereject = {0};
+static stralloc headerreject = {0};
 
-struct constmap mimeremovemap;
-struct constmap mimerejectmap;
-struct constmap headerrejectmap;
-int mimeremoveflag = 0;
-
-char strnum[FMT_ULONG];
-char buf0[256];
-substdio ssin = SUBSTDIO_FDBUF(read,0,buf0,(int) sizeof(buf0));
-substdio ssin2 = SUBSTDIO_FDBUF(read,0,buf0,(int) sizeof(buf0));
+static struct constmap mimeremovemap;
+static struct constmap mimerejectmap;
+static struct constmap headerrejectmap;
+static int mimeremoveflag = 0;
 
 struct qmail qq;
 
-stralloc line = {0};
-stralloc to = {0};
-stralloc content = {0};
-stralloc subject = {0};
-stralloc boundary = {0};
-stralloc precd = {0};
-stralloc mydtline = {0};
+static stralloc line = {0};
+static stralloc to = {0};
+static stralloc content = {0};
+static stralloc subject = {0};
+static stralloc boundary = {0};
+static stralloc precd = {0};
+static stralloc mydtline = {0};
 
-unsigned int findlocal(const stralloc *sa,unsigned int n)
+static unsigned int findlocal(const stralloc *sa,unsigned int n)
 	/* n is index of '@' within sa. Returns index to last postition */
 	/* of local, n otherwise. */
 {
@@ -119,7 +115,7 @@ unsigned int findlocal(const stralloc *sa,unsigned int n)
   return n;
 }
 
-unsigned int findhost(const stralloc *sa,unsigned int n)
+static unsigned int findhost(const stralloc *sa,unsigned int n)
 	/* s in index to a '@' within sa. Returns index to first pos of */
 	/* host part if there is one, n otherwise. */
 {
@@ -154,7 +150,7 @@ unsigned int findhost(const stralloc *sa,unsigned int n)
   return n;
 }
 
-int getto(const stralloc *sa)
+static int getto(const stralloc *sa)
 	/* find list address in line. If found, return 1, else return 0. */
 {
   unsigned int pos = 0;
@@ -182,13 +178,16 @@ int main(int argc,char **argv)
   unsigned long maxmsgsize = 0L;
   unsigned long minmsgsize = 0L;
   unsigned long msgsize = 0L;
-  char linetype = ' ';
   char *cp, *cpstart, *cpafter;
   const char *dir;
   const char *err;
   const char *sender;
   unsigned int len;
   int match;
+  char strnum[FMT_ULONG];
+  char buf0[4096];
+  substdio ssin = SUBSTDIO_FDBUF(read,0,buf0,(int) sizeof(buf0));
+  substdio ssin2 = SUBSTDIO_FDBUF(read,0,buf0,(int) sizeof(buf0));
 
   getconfopt(argc,argv,options,-1,&dir);
   if (dir) {
@@ -233,7 +232,7 @@ int main(int argc,char **argv)
     constmap_init(&headerrejectmap,headerreject.s,headerreject.len,0);
   }
   for (;;) {
-    if (getln(&ssin,&line,&match,'\n') == -1)
+    if (gethdrln(&ssin,&line,&match,'\n') == -1)
       strerr_die2sys(111,FATAL,MSG(ERR_READ_INPUT));
     if (!match) break;
     if (flagheaderreject && dir)
@@ -242,37 +241,22 @@ int main(int argc,char **argv)
 
     if (line.len == 1) break;
     cp = line.s; len = line.len;
-    if ((*cp == ' ' || *cp == '\t')) {
-      switch(linetype) {
-	case 'T': if (!stralloc_catb(&to,cp,len-1)) die_nomem(); break;
-	case 'S': if (!stralloc_catb(&subject,cp,len-1)) die_nomem(); break;
-	case 'C': if (!stralloc_catb(&content,cp,len-1)) die_nomem(); break;
-	case 'P': if (!stralloc_catb(&precd,cp,len-1)) die_nomem(); break;
-	default: break;
-      }
-    } else {
       if (!flagtook &&
 		(case_startb(cp,len,"to:") || case_startb(cp,len,"cc:"))) {
-	linetype = 'T';		/* cat so that To/Cc don't overwrite */
         if (!stralloc_catb(&to,line.s + 3,line.len - 4)) die_nomem();
       } else if ((flagneedsubject || flagrejectcommands) &&
 			 case_startb(cp,len,"subject:")) {
-	if (!stralloc_copyb(&subject,cp+8,len-9)) die_nomem();
-	linetype = 'S';
+	concatHDR(cp+8,len-8,&subject);
       } else if (case_startb(cp,len,"content-type:")) {
-	if (!stralloc_copyb(&content,cp+13,len-14)) die_nomem();
-	linetype = 'C';
+	concatHDR(cp+13,len-13,&content);
       } else if (case_startb(cp,len,"precedence:")) {
-	if (!stralloc_copyb(&precd,cp+11,len-12)) die_nomem();
-	linetype = 'P';
+	concatHDR(cp+11,len-11,&precd);
       } else {
 	if (flagforward && line.len == mydtline.len) {
 	  if (!byte_diff(line.s,line.len,mydtline.s))
             strerr_die2x(100,FATAL,MSG(ERR_LOOPING));
         }
-        linetype = ' ';
       }
-    }
   }
   if (precd.len >= 4 &&
 		(!case_diffb(precd.s + precd.len - 4,4,"junk") ||
@@ -280,8 +264,7 @@ int main(int argc,char **argv)
 	  strerr_die1x(99,MSG(ERR_JUNK));	/* ignore precedence junk/bulk */
   cp = subject.s;
   len = subject.len;
-  while (len && (cp[len-1] == ' ' || cp[len-1] == '\t')) --len;
-  while (len && ((*cp == ' ') || (*cp == '\t'))) { ++cp; --len; }
+  while (len && (cp[len-1] == ' ' || cp[len-1] == '\t' || cp[len-1] == '\n')) --len;
   flaghavesubject = 1;
 
   if (flagbody)
@@ -341,7 +324,6 @@ int main(int argc,char **argv)
   if (content.len) {			/* MIME header */
     cp = content.s;
     len = content.len;
-    while (len && (*cp == ' ' || *cp == '\t')) { ++cp; --len; }
     cpstart = cp;
     if (*cp == '"') {			/* might be commented */
       ++cp; cpstart = cp;
