@@ -50,38 +50,28 @@ static struct option options[] = {
   OPT_END
 };
 
-char strnum[FMT_ULONG];
-
-char *userlocal = (char *) 0;
-char *userhost = (char *) 0;
-char *listlocal = (char *) 0;
-char *listhost = (char *) 0;
-char *command = (char*)"help";
+static char *userlocal = (char *) 0;
+static char *userhost = (char *) 0;
+static char *listlocal = (char *) 0;
+static char *listhost = (char *) 0;
+static char *command = (char*)"help";
 stralloc line = {0};
-stralloc qline = {0};
-stralloc usr = {0};
-stralloc lhost = {0};
-stralloc subject = {0};
-stralloc listname = {0};
-stralloc hostname = {0};
-stralloc headerremove = {0};
-stralloc cmds = {0};
-stralloc from = {0};
-stralloc to = {0};
+static stralloc listname = {0};
+static stralloc hostname = {0};
 stralloc quoted = {0};
 char boundary[COOKIE] = "zxcaeedrqcrtrvthbdty";	/* cheap "rnd" MIME boundary */
 
-struct constmap headerremovemap;
-int headerremoveflag = 0;
-struct constmap commandmap;
-int flaggotsub = 0;		/* Found a subject */
+static struct constmap headerremovemap;
+static int headerremoveflag = 0;
+static struct constmap commandmap;
+static int flaggotsub = 0;		/* Found a subject */
 	/* cmdstring has all commands seperated by '\'. cmdxlate maps each */
 	/* command alias to the basic command, which is used to construct  */
 	/* the command address (positive numbers) or handled by this       */
 	/* program (negative numbers). Note: Any command not matched is    */
 	/* used to make a command address, so ezmlm request can handle     */
 	/* ("transmit") user-added commands.                               */
-const char cmdstring[] =
+static const char cmdstring[] =
 		"system\\help\\"			/* 1,2 */
 		"subscribe\\unsubscribe\\index\\"	/* 3,4,5 */
 		"info\\list\\query\\"			/* 6,7,8 */
@@ -95,16 +85,16 @@ const char cmdstring[] =
 	/* help and arguments scrapped. < 0 handled locally. HELP without    */
 	/* args also handled locally */
 			/* the last are not supported -> help */
-const int cmdxlate[] = { 0,1,2,3,4,5,6,7,8,3,4,4,4,-13,-14,5,7,7,7,7,7,
-			1,1 };
+static const int cmdxlate[] = { 0,1,2,3,4,5,6,7,8,3,4,4,4,-13,-14,5,7,7,7,7,7,
+				1,1 };
 
 	/* If there are no arguments (listlocal = 0) then commands are mapped*/
 	/* through this. This way, help, list, query, ... can mean something */
 	/* here even though they have local funcions at the lists if used    */
 	/* with arguments. (Made same lengh as cmdxlate in case of bugs.)    */
 	/* Note: This is used ONLY for the global interface */
-const int noargsxlate[] = { 0,1,-2,3,4,5,-2,-13,-14,9,10,11,12,13,14,15,16,17,
-			18,19,20,21,22 };
+static const int noargsxlate[] = { 0,1,-2,3,4,5,-2,-13,-14,9,10,11,12,13,14,15,16,17,
+				   18,19,20,21,22 };
 
 	/* these need to be defined as the index of the corresponding      */
 	/* commands. They are handled by ezmlm-request. NOTE: Help is >0!  */
@@ -113,19 +103,21 @@ const int noargsxlate[] = { 0,1,-2,3,4,5,-2,-13,-14,9,10,11,12,13,14,15,16,17,
 #define EZREQ_HELP  2
 #define EZREQ_BAD 1
 
-substdio sstext;
-char textbuf[1024];
+static substdio sstext;
+static char textbuf[1024];
 
 struct qmail qq;
 
-char inbuf[1024];
-substdio ssin = SUBSTDIO_FDBUF(read,0,inbuf,(int) sizeof(inbuf));
-substdio ssin2 = SUBSTDIO_FDBUF(read,0,inbuf,(int) sizeof(inbuf));
+static char inbuf[1024];
+static substdio ssin = SUBSTDIO_FDBUF(read,0,inbuf,(int) sizeof(inbuf));
+static substdio ssin2 = SUBSTDIO_FDBUF(read,0,inbuf,(int) sizeof(inbuf));
 
-stralloc mydtline = {0};
+static stralloc mydtline = {0};
 
-int code_qput(const char *s,unsigned int n)
+static int code_qput(const char *s,unsigned int n)
 {
+  static stralloc qline = {0};
+
     if (!flagcd)
       qmail_put(&qq,s,n);
     else {
@@ -140,7 +132,7 @@ int code_qput(const char *s,unsigned int n)
 
 /* Checks the argument. Only  us-ascii letters, numbers, ".+-_" are ok. */
 /* NOTE: For addresses this is more restrictive than rfc821/822.        */
-void checkarg(const char *s)
+static void checkarg(const char *s)
 {
   const char *cp;
   char ch;
@@ -178,7 +170,7 @@ void checkarg(const char *s)
 /* is accepted to allow commands that take arguments that are not       */
 /* addresses (e.g. -get12-34).                                          */
 
-void parseline(char *cp)
+static void parseline(char *cp)
 {
   char *cp1;
   char *cp2;
@@ -189,9 +181,8 @@ void parseline(char *cp)
     if (*cp1 == '\t') *cp1 = ' ';
     ++cp1;
   }
-					/* NOTE: listname has '\0' added! */
-  if (listname.len < str_len(cp) && cp[listname.len -1] == '-' &&
-	case_starts(cp,listname.s))	 {	/* normal ezmlm cmd */
+  if (str_len(cp) >= outlocal.len && cp[outlocal.len] == '-'
+      && case_startb(cp,outlocal.len,outlocal.s)) {	/* normal ezmlm cmd */
     command = cp + listname.len;		/* after the '-' */
     listlocal = listname.s;
     listhost = hostname.s;
@@ -269,7 +260,6 @@ int main(int argc,char **argv)
   char *psz;
   const char *err;
   int cmdidx;
-  int flagsub;
   int flagok;
   int flagnosubject;
   int match;
@@ -278,6 +268,14 @@ int main(int argc,char **argv)
   int flagmultipart = 0;
   int fd;
   unsigned int pos,pos1,len,last;
+  char strnum[FMT_ULONG];
+  stralloc usr = {0};
+  stralloc lhost = {0};
+  stralloc subject = {0};
+  stralloc headerremove = {0};
+  stralloc cmds = {0};
+  stralloc from = {0};
+  stralloc to = {0};
 
   (void)umask(022);
   sig_pipeignore();
@@ -333,9 +331,9 @@ int main(int argc,char **argv)
 
   if (!stralloc_copys(&mydtline,
        "Delivered-To: request processor for ")) die_nomem();
-  if (!stralloc_cats(&mydtline,listname.s)) die_nomem();
+  if (!stralloc_cat(&mydtline,&outlocal)) die_nomem();
   if (!stralloc_cats(&mydtline,"@")) die_nomem();
-  if (!stralloc_cats(&mydtline,hostname.s)) die_nomem();
+  if (!stralloc_cat(&mydtline,&outhost)) die_nomem();
   if (!stralloc_cats(&mydtline,"\n")) die_nomem();
 
   flagnosubject = 1;
@@ -355,24 +353,17 @@ int main(int argc,char **argv)
       }
     }
   } else {
-    for (flagsub = 0;;) {			/* Get Subject: */
-      if (getln(&ssin,&line,&match,'\n') == -1)
+    for (;;) {			/* Get Subject: */
+      if (gethdrln(&ssin,&line,&match,'\n') == -1)
         strerr_die2sys(111,FATAL,MSG(ERR_READ_INPUT));
       if (line.len <= 1)
         break;
-      if ((line.s[0] != ' ') && (line.s[0] != '\t')) {
-          flagsub = 0;
 
           if (case_startb(line.s,line.len,"mailing-list:"))
             strerr_die2x(100,FATAL,MSG(ERR_MAILING_LIST));
           else if (case_startb(line.s,line.len,"Subject:")) {
-            flagsub = flaggotsub = 1;
-            pos = 8;
-            last = line.len - 2;		/* skip terminal '\n' */
-            while (line.s[last] == ' ' || line.s[last] == '\t') --last;
-            while (pos <= last &&
-		(line.s[pos] == ' ' || line.s[pos] == '\t')) ++pos;
-            if (!stralloc_copyb(&subject,line.s+pos,last-pos+1)) die_nomem();
+            flaggotsub = 1;
+	    concatHDR(line.s+8,line.len-8,&subject);
           } else if (case_startb(line.s,line.len,"content-type:")) {
 	    pos = 13; last = line.len - 2;	/* not cont-line - ok */
             while (pos <= last &&
@@ -382,15 +373,6 @@ int main(int argc,char **argv)
 	  } else if (line.len == mydtline.len)
             if (!byte_diff(line.s,line.len,mydtline.s))
                strerr_die2x(100,FATAL,MSG(ERR_LOOPING));
-      } else if (flagsub) {	/* Continuation line */
-          pos = 1;
-          len = line.len - 2;	/* skip terminal '\n' */
-          while (line.s[len] == ' ' || line.s[len] == '\t') --len;
-          while (pos < len &&
-		(line.s[pos] == ' ' || line.s[pos] == '\t')) ++pos;
-          if (!stralloc_append(&subject," ")) die_nomem();
-          if (!stralloc_catb(&subject,line.s+pos,len-pos+1)) die_nomem();
-      }
       if (!match)
 	break;
     }
@@ -398,7 +380,7 @@ int main(int argc,char **argv)
       char ch;
       if (!stralloc_0(&subject)) die_nomem();
       ch = *subject.s;		/* valid commands/list names start w letter */
-      if ((ch <= 'z' && ch >= 'a') || (ch <= 'Z' && ch >= 'A')) {
+      if ((ch <= 'z' && ch >= 'a') || (ch <= 'Z' && ch >= 'A') || ch == '_') {
         parseline(subject.s);
         flagnosubject = 0;
       }
@@ -588,9 +570,9 @@ int main(int argc,char **argv)
       userhost = listhost; listhost = 0;
       initsub(0);
     }
-    if (!stralloc_copys(&from,listname.s)) die_nomem();
+    if (!stralloc_copy(&from,&outlocal)) die_nomem();
     if (!stralloc_cats(&from,"-return-@")) die_nomem();
-    if (!stralloc_cats(&from,hostname.s)) die_nomem();
+    if (!stralloc_cat(&from,&outhost)) die_nomem();
     if (!stralloc_0(&from)) die_nomem();
 
     if (userlocal) {
@@ -599,7 +581,7 @@ int main(int argc,char **argv)
       if (userhost) {
         if (!stralloc_cats(&to,userhost)) die_nomem();
        } else {
-        if (!stralloc_cats(&to,hostname.s)) die_nomem();
+        if (!stralloc_cat(&to,&outhost)) die_nomem();
       }
     } else
       if (!stralloc_copys(&to,sender)) die_nomem();
