@@ -30,6 +30,7 @@
 #include "messages.h"
 #include "makehash.h"
 #include "cookie.h"
+#include "dmarc.h"
 #include "hdr.h"
 #include "die.h"
 #include "wrap.h"
@@ -38,10 +39,10 @@
 #include "config.h"
 #include "auto_version.h"
 
-int flagnoreceived = 1;		/* suppress received headers by default. They*/
+static int flagnoreceived = 1;	/* suppress received headers by default. They*/
 				/* are still archived. =0 => archived and */
 				/* copied. */
-int flaglog = 1;		/* for lists with mysql support, use tags */
+static int flaglog = 1;		/* for lists with mysql support, use tags */
 				/* and log traffic to the database */
 const char FATAL[] = "ezmlm-send: fatal: ";
 const char USAGE[] =
@@ -50,6 +51,8 @@ const char USAGE[] =
 static int ignoredflag;
 static const char *hash_str = 0;
 static char *mlheader = 0;
+static int flagrewritefrom = 0;
+static int flagreplytolist = 0;
 
 static struct option options[] = {
   OPT_FLAG(ignoredflag,'c',0,0), /* ignore for backwards compat */
@@ -63,78 +66,71 @@ static struct option options[] = {
   OPT_CSTR(hash_str,'S',0),
   OPT_FLAG(ignoredflag,'q',0,0),
   OPT_FLAG(ignoredflag,'Q',0,0),
+  OPT_FLAG(flagrewritefrom,0,1,"rewritefrom"),
+  OPT_FLAG(flagreplytolist,0,1,"replytolist"),
   OPT_END
 };
 
-	/* for writing new index file indexn later moved to index. */
-substdio ssindexn;
-char indexnbuf[1024];
-
-char strnum[FMT_ULONG];
-char szmsgnum[FMT_ULONG];
-char hash[HASHLEN];
-
-stralloc fnadir = {0};
-stralloc fnaf = {0};
-stralloc fnif = {0};
-stralloc fnifn = {0};
-stralloc fnsub = {0};
-stralloc line = {0};
-stralloc qline = {0};
-stralloc lines = {0};
-stralloc subject = {0};
-stralloc from = {0};
-stralloc received = {0};
-stralloc prefix = {0};
-stralloc content = {0};
+static stralloc fnadir = {0};
+static stralloc fnaf = {0};
+static stralloc fnif = {0};
+static stralloc fnifn = {0};
+static stralloc line = {0};
+static stralloc qline = {0};
+static stralloc lines = {0};
+static stralloc subject = {0};
+static stralloc from = {0};
+static stralloc received = {0};
+static stralloc prefix = {0};
+static stralloc content = {0};
 stralloc boundary = {0};
-stralloc dcprefix = {0};
-stralloc dummy = {0};
+static stralloc dcprefix = {0};
+static stralloc dummy = {0};
+static stralloc author = {0};
 
 void die_indexn(void)
 {
   strerr_die2sys(111,FATAL,MSG1(ERR_WRITE,fnifn.s));
 }
 
-unsigned long innum;
-unsigned long outnum;
-unsigned long msgnum = 0L;
-unsigned long hash_lo = 0L;
-unsigned long hash_hi = 52L;
-unsigned long msgsize = 0L;
-unsigned long cumsize = 0L;	/* cumulative archive size bytes / 256 */
-char encin = '\0';
-int flagindexed;
-int flagfoundokpart;		/* Found something to pass on. If multipart */
-				/* we set to 0 and then set to 1 for any */
-				/* acceptable mime part. If 0 -> reject */
-int flagsawreceived;
-int flagprefixed;
-unsigned int serial = 0;
-int flagarchived;
-int fdarchive;
-int fdindex;
-int fdindexn;
-char hashout[COOKIE+1];
+void die_dns(const char *domain)
+{
+  strerr_die2sys(111,FATAL,MSG1(ERR_DNS_LOOKUP,domain));
+}
 
-substdio ssarchive;
-char archivebuf[1024];
+static unsigned long innum;
+static unsigned long outnum;
+static unsigned long msgnum = 0L;
+static unsigned long hash_lo = 0L;
+static unsigned long hash_hi = 52L;
+static unsigned long msgsize = 0L;
+static unsigned long cumsize = 0L;	/* cumulative archive size bytes / 256 */
+static char encin = '\0';
+static int flagindexed;
+static int flagfoundokpart;		/* Found something to pass on. If multipart */
+					/* we set to 0 and then set to 1 for any */
+					/* acceptable mime part. If 0 -> reject */
+static int flagsawreceived;
+static int flagprefixed;
+static unsigned int serial = 0;
+static int flagarchived;
+static int fdarchive;
+static int fdindex;
+static int fdindexn;
 
-int flagsublist;
-stralloc sublist = {0};
-stralloc headerremove = {0};
-struct constmap headerremovemap;
-int headerremoveflag = 0;
-stralloc mimeremove = {0};
-struct constmap mimeremovemap;
-int mimeremoveflag = 0;
+static substdio ssarchive;
+static char archivebuf[1024];
+
+static int flagsublist;
+static stralloc sublist = {0};
+static stralloc headerremove = {0};
+static struct constmap headerremovemap;
+static int headerremoveflag = 0;
+static stralloc mimeremove = {0};
+static struct constmap mimeremovemap;
+static int mimeremoveflag = 0;
 
 struct qmail qq;
-substdio ssin;
-char inbuf[1024];
-
-char textbuf[512];
-substdio sstext;
 
 int subto(const char *s,unsigned int l)
 {
@@ -162,9 +158,7 @@ void qa_put(const char *buf,unsigned int len)
 
 void qa_puts(const char *buf)
 {
-  qmail_puts(&qq,buf);
-  if (flagarchived)
-    if (substdio_puts(&ssarchive,buf) == -1) die_archive();
+  qa_put(buf,str_len(buf));
 }
 
 int sublistmatch(const char *sender)
@@ -185,12 +179,12 @@ int sublistmatch(const char *sender)
   return 1;
 }
 
-substdio ssnumnew;
-char numnewbuf[16];
-
 void numwrite(void)
 {		/* this one deals with msgnum, not outnum! */
   int fd;
+  substdio ssnumnew;
+  char numnewbuf[16];
+  char strnum[FMT_ULONG];
 
   fd = open_trunc("numnew");
   if (fd == -1) die_numnew();
@@ -208,8 +202,6 @@ void numwrite(void)
   wrap_rename("numnew","num");
 }
 
-stralloc mydtline = {0};
-
 int idx_copy_insertsubject(void)
 /* copies old index file up to but not including msg, then adds a line with */
 /* 'sub' trimmed of reply indicators, then closes the new index and moves it*/
@@ -219,12 +211,17 @@ int idx_copy_insertsubject(void)
 /* returns 1 if reply-indicators were found, 0 otherwise.                   */
 /* no terminal \n or \0 in any of the strallocs! */
 {
-  char *cp;
   unsigned long idx;
   int match;
   int r;
   unsigned int pos;
-  int k;
+  substdio ssin;
+  char inbuf[1024];
+  /* for writing new index file indexn later moved to index. */
+  substdio ssindexn;
+  char indexnbuf[1024];
+  char strnum[FMT_ULONG];
+  char hash[HASHLEN];
 
   if (!stralloc_copys(&fnadir,"archive/")) die_nomem();
   if (!stralloc_catb(&fnadir,strnum,fmt_ulong(strnum,outnum / 100)))
@@ -302,8 +299,7 @@ int idx_copy_insertsubject(void)
   if (!stralloc_catb(&qline,hash,HASHLEN)) die_nomem();
   if (!stralloc_cats(&qline," ")) die_nomem();
 
-  k = author_name(&cp,lines.s,lines.len);
-  decodeHDR(cp,k,&from);
+  author_name(&from,lines.s,lines.len);
 
   (void) unfoldHDR(from.s,from.len,&lines,charset.s,&dcprefix,0);
   if (!stralloc_cat(&qline,&lines)) die_nomem();
@@ -318,10 +314,48 @@ int idx_copy_insertsubject(void)
   return r;
 }
 
+static void rewrite_from()
+{
+  unsigned int at;
+  int r;
+
+  /* If not unconditionally rewriting headers, turn it on for this
+   * message if DMARC would prevent us from sending as-is. */
+  if (!flagrewritefrom) {
+    concatHDR(from.s,from.len,&lines);
+    author_addr(&author,lines.s,lines.len);
+    at = byte_rchr(author.s,author.len,'@');
+    if (++at >= author.len)
+      return;
+    if (!stralloc_copyb(&dummy,author.s + at,author.len - at)) die_nomem();
+    if (!stralloc_0(&dummy)) die_nomem();
+    r = dmarc_p_reject(dummy.s);
+    if (r < 0) die_dns(dummy.s);
+    flagrewritefrom = r;
+  }
+
+  if (flagrewritefrom) {
+    concatHDR(from.s,from.len,&lines);
+    author_name(&author,lines.s,lines.len);
+    stralloc_0(&author);
+    stralloc_copy(&dummy,&outlocal);
+    stralloc_0(&dummy);
+
+    if (!stralloc_copyb(&line,"From: \"",7)) die_nomem();
+    if (!stralloc_cats(&line,MSG2(AUTHOR_VIA_LIST,author.s,dummy.s))) die_nomem();
+    if (!stralloc_catb(&line,"\" <",3)) die_nomem();
+    if (!stralloc_catb(&line,outlocal.s,outlocal.len)) die_nomem();
+    if (!stralloc_catb(&line,"@",1)) die_nomem();
+    if (!stralloc_catb(&line,outhost.s,outhost.len)) die_nomem();
+    if (!stralloc_catb(&line,">\n",2)) die_nomem();
+    if (!stralloc_cats(&line,flagreplytolist ? "Cc:" : "Reply-To:")) die_nomem();
+    if (!stralloc_catb(&line,from.s,from.len)) die_nomem();
+  }
+}
+
 int main(int argc,char **argv)
 {
   unsigned long subs;
-  int fdlock;
   const char *sender;
   const char *ret;
   const char *err;
@@ -336,9 +370,12 @@ int main(int argc,char **argv)
   int flagseenext;
   int flagarchiveonly;
   int flagtrailer;
-  enum { no_prev_line, subject_line, from_line, content_line, received_line } prevline;
   unsigned int pos;
   char *cp, *cpstart, *cpafter;
+  stralloc mydtline = {0};
+  char strnum[FMT_ULONG];
+  char szmsgnum[FMT_ULONG];
+  char hashout[COOKIE+1];
 
   umask(022);
   sig_pipeignore();
@@ -361,7 +398,7 @@ int main(int argc,char **argv)
 
   sender = get_sender();
 
-  fdlock = lockfile("lock");
+  lockfile("lock");
 
   flagarchived = getconf_isset("archived");
   flagindexed = getconf_isset("indexed");
@@ -464,6 +501,14 @@ int main(int argc,char **argv)
   }
   copy(&qq,"headeradd",'H');
   qa_put(mydtline.s,mydtline.len);
+  if (flagreplytolist) {
+    if (!stralloc_copyb(&line,"Reply-To: <",11)) die_nomem();
+    if (!stralloc_cat(&line,&outlocal)) die_nomem();
+    if (!stralloc_append(&line,'@')) die_nomem();
+    if (!stralloc_cat(&line,&outhost)) die_nomem();
+    if (!stralloc_catb(&line,">\n",2)) die_nomem();
+    qa_put(line.s,line.len);
+  }
 
   flagmlwasthere = 0;
   flaginheader = 1;
@@ -473,9 +518,8 @@ int main(int argc,char **argv)
   flagseenext = 0;
   flagsawreceived = 0;
   flagarchiveonly = 0;
-  prevline = no_prev_line;
   for (;;) {
-    if (getln(subfdin,&line,&match,'\n') == -1)
+    if (gethdrln(subfdin,&line,&match,'\n') == -1)
       strerr_die2sys(111,FATAL,MSG(ERR_READ_INPUT));
     if (flaginheader && match) {
       if (line.len == 1) {		/* end of header */
@@ -544,11 +588,12 @@ int main(int argc,char **argv)
             }
           }
         }
-      } else if ((*line.s != ' ') && (*line.s != '\t')) {
+      } else {
         flagbadfield = headerremoveflag;
         flagarchiveonly = 0;
-	prevline = no_prev_line;
-	if (constmap(&headerremovemap,line.s,byte_chr(line.s,line.len,':')))
+	if (flagreplytolist && case_startb(line.s,line.len,"reply-to:"))
+	  flagbadfield = 1;
+	else if (constmap(&headerremovemap,line.s,byte_chr(line.s,line.len,':')))
 	  flagbadfield = !headerremoveflag;
         if ((flagnoreceived || !flagsawreceived) &&
 		case_startb(line.s,line.len,"Received:")) {
@@ -561,7 +606,6 @@ int main(int argc,char **argv)
 		    break;
                 if (!stralloc_copyb(&received,line.s+pos,line.len-pos-1))
                   die_nomem();
-		prevline = received_line;
 	      }
             } else {				/* suppress, but archive */
               flagarchiveonly = 1;		/* but do not suppress the */
@@ -574,10 +618,8 @@ int main(int argc,char **argv)
         else if ((mimeremove.len || flagtrailer) &&	/* else no MIME need*/
 		case_startb(line.s,line.len,"Content-Type:")) {
           if (!stralloc_copyb(&content,line.s+13,line.len-13)) die_nomem();
-          prevline = content_line;
 	} else if (case_startb(line.s,line.len,"Subject:")) {
           if (!stralloc_copyb(&subject,line.s+8,line.len-8)) die_nomem();
-	  prevline = subject_line;
           if (flagprefixed && !flagsublist)	/* don't prefix for sublists */
 	    flagbadfield = 1;			/* we'll print our own */
         } else if (flagtrailer &&
@@ -589,33 +631,12 @@ int main(int argc,char **argv)
           else if (case_startb(cp,cpafter-cp,"Quoted-Printable")) encin = 'Q';
         } else if (flaglistid && case_startb(line.s,line.len,"list-id:"))
 	  flagbadfield = 1;		/* suppress if we added our own */
-	else if (flagindexed) {
-
-          if (case_startb(line.s,line.len,"From:")) {
-            prevline = from_line;
-            if (!stralloc_copyb(&from,line.s+5,line.len-5)) die_nomem();
-          }
+	else if (case_startb(line.s,line.len,"From:")) {
+	  if (!stralloc_copyb(&from,line.s+5,line.len-5)) die_nomem();
+	  rewrite_from();
         } else if (line.len == mydtline.len)
 	  if (!byte_diff(line.s,line.len,mydtline.s))
             strerr_die2x(100,FATAL,MSG(ERR_LOOPING));
-      } else {			/* continuation lines */
-	switch (prevline) {
-	case subject_line:
-	  if (!stralloc_cat(&subject,&line)) die_nomem();
-	  break;
-	case from_line:
-	  if (!stralloc_cat(&from,&line)) die_nomem();
-	  break;
-	case content_line:
-          if (!stralloc_cat(&content,&line)) die_nomem();
-	  break;
-	case received_line:
-	  for (pos = 1; pos < line.len; ++pos)
-	    if (line.s[pos] != ' ' && line.s[pos] != '\t')
-	      break;
-	  if (!stralloc_catb(&received,line.s+pos,line.len-pos-1)) die_nomem();
-	  break;
-	}
       }
     } else				/* body */
       msgsize += line.len;		/* always for tstdig support */
