@@ -42,31 +42,31 @@ static struct option options[] = {
   OPT_END
 };
 
-const char *sender;
-const char *split;
-stralloc target = {0};
-stralloc lctarget = {0};
-stralloc line = {0};
-stralloc domain = {0};
-stralloc name = {0};
-stralloc from = {0};
-stralloc to = {0};
-char strnum[FMT_ULONG];
-unsigned long lineno;
-int flagfound;
+static const char *sender;
+static const char *split;
+static stralloc target = {0};
+static stralloc lctarget = {0};
+static stralloc line = {0};
+static stralloc domain = {0};
+static stralloc name = {0};
+static stralloc from = {0};
+static stralloc to = {0};
+static unsigned long lineno;
+static int flagfound;
 
-void die_syntax(void)
+static void die_syntax(void)
 {
+  char strnum[FMT_ULONG];
   strnum[fmt_ulong(strnum,lineno)] = '\0';
   strerr_die6x(111,FATAL,split," syntax error line ",strnum,": ",line.s);
 }
 
-char spbuf[1024];	/* should normally hold entire file */
-substdio sssp;
+static char spbuf[1024];	/* should normally hold entire file */
+static substdio sssp;
 
 struct qmail qq;
 
-int findname(void)
+static int findname(void)
 /* returns 1 if a matching line was found, 0 otherwise. name will contain */
 /* the correct list address in either case */
 {
@@ -96,7 +96,7 @@ int findname(void)
     cp2 = cpat + byte_rchr(cpat, cp1 - cpat,'.');
     if (cp2 == cp1) cp2 = cpat;
     ++cp2;
-    if (!stralloc_append(&domain,".")) die_nomem();
+    if (!stralloc_append(&domain,'.')) die_nomem();
     if (!stralloc_catb(&domain,cp2, cp1 - cp2)) die_nomem();
   } else				/* no '.' */
     if (!stralloc_copyb(&domain,cpat + 1,cplast - cpat)) die_nomem();
@@ -149,14 +149,14 @@ int findname(void)
   if (*cpname) {
     if (!stralloc_copys(&name,cpname)) die_nomem();
     if (byte_chr(name.s,name.len,'@') == name.len) {	/* local sublist */
-      if (!stralloc_append(&name,"@")) die_nomem();
+      if (!stralloc_append(&name,'@')) die_nomem();
       if (!stralloc_cat(&name,&outhost)) die_nomem();
     }
     if (!stralloc_0(&name)) die_nomem();
     return 1;
   } else {			/* match without name or no match =>this list */
     if (!stralloc_copy(&name,&outlocal)) die_nomem();
-    if (!stralloc_append(&name,"@")) die_nomem();
+    if (!stralloc_append(&name,'@')) die_nomem();
     if (!stralloc_cat(&name,&outhost)) die_nomem();
     if (!stralloc_0(&name)) die_nomem();
     return 0;
@@ -165,6 +165,7 @@ int findname(void)
 
 int main(int argc,char **argv)
 {
+  char strnum[FMT_ULONG];
   char *action;
   char *dtline;
   char *nhost;
@@ -219,13 +220,13 @@ int main(int argc,char **argv)
       nhost = name.s + str_rchr(name.s,'@');		/* name must have '@'*/
       *(nhost++) = '\0';
       if (!stralloc_copys(&to,name.s)) die_nomem();	/* local */
-      if (!stralloc_append(&to,"-")) die_nomem();	/* - */
+      if (!stralloc_append(&to,'-')) die_nomem();	/* - */
       if (!stralloc_cats(&to,action)) die_nomem();	/* subscribe */
-      if (!stralloc_append(&to,"-")) die_nomem();	/* - */
+      if (!stralloc_append(&to,'-')) die_nomem();	/* - */
       if (target.s[i = str_rchr(target.s,'@')])
 	target.s[i] = '=';
       if (!stralloc_cats(&to,target.s)) die_nomem();	/* target */
-      if (!stralloc_append(&to,"@")) die_nomem();	/* - */
+      if (!stralloc_append(&to,'@')) die_nomem();	/* - */
       if (!stralloc_cats(&to,nhost)) die_nomem();	/* host */
       if (!stralloc_0(&to)) die_nomem();
       dtline = env_get("DTLINE");
@@ -259,7 +260,7 @@ int main(int argc,char **argv)
       (void) findname();
       if (!stralloc_cats(&name,": ")) die_nomem();
       if (!stralloc_cats(&name,target.s)) die_nomem();
-      if (!stralloc_append(&name,"\n")) die_nomem();
+      if (!stralloc_append(&name,'\n')) die_nomem();
       if (substdio_put(subfdout,name.s,name.len) == -1)
 	strerr_die2sys(111,FATAL,MSG(ERR_WRITE_STDOUT));
     }
