@@ -37,15 +37,6 @@ static struct option options[] = {
   OPT_END
 };
 
-stralloc line = {0};
-
-substdio ssnum;
-char numbuf[16];
-
-char strnum[FMT_ULONG];
-
-int flaglocal = 0;
-
 int main(int argc,char **argv)
 {
   char *local;
@@ -54,7 +45,12 @@ int main(int argc,char **argv)
   unsigned long num, digsize, dignum;
   unsigned long cumsize = 0L;
   unsigned long when, tsttime, digwhen;
-  int fd,fdlock;
+  int fd;
+  stralloc line = {0};
+  substdio ssnum;
+  char numbuf[16];
+  char strnum[FMT_ULONG];
+  int flaglocal = 0;
 
   (void) umask(022);
   sig_pipeignore();
@@ -101,7 +97,7 @@ int main(int argc,char **argv)
       (deltanum && ((dignum + deltanum) <= num))) {	/* digest! */
     if (flaglocal) {	/* avoid multiple digests. Of course, ezmlm-tstdig*/
 			/* belongs in ezmlm-digest, but it's too late ....*/
-      fdlock = lockfile("lock");
+      lockfile("lock");
       getconf_line(&line,"tstdig",0);
       if (!stralloc_0(&line)) die_nomem();
       scan_ulong(line.s,&tsttime);	/* give digest 1 h to complete */
