@@ -2,7 +2,7 @@
 
 const char FATAL[] = "ezmlm-unsub: fatal: ";
 const char USAGE[] =
-"ezmlm-unsub: usage: ezmlm-unsub [-h hash] [-HmMnNvV] dir [subdir] [box@domain ...]";
+"ezmlm-unsub: usage: ezmlm-unsub [-HmMnNvV] [-h hash] [-t tag] dir [subdir] [box@domain ...]";
 
 extern void subunsub_main(int submode,int argc,char **argv) __attribute__((noreturn));
 
