@@ -38,14 +38,14 @@ const char FATAL[] = "ezmlm-warn: fatal: ";
 const char USAGE[] =
 "ezmlm-warn: usage: ezmlm-warn -dD -l secs -t days dir";
 
-static int flagdig = -1;
+static int digopt = -1;
 static unsigned long lockout = 0L;
 static unsigned long bouncetimeout = BOUNCE_TIMEOUT;
 static int nowarn = 0;
-unsigned long copylines = 0;	/* Number of lines from the message to copy */
+static unsigned long copylines = 0;	/* Number of lines from the message to copy */
 static struct option options[] = {
-  OPT_FLAG(flagdig,'d',1,0),
-  OPT_FLAG(flagdig,'D',0,0),
+  OPT_FLAG(digopt,'d',1,0),
+  OPT_FLAG(digopt,'D',0,0),
   OPT_ULONG(lockout,'l',0),
   OPT_ULONG(bouncetimeout,'t',0),
   OPT_ULONG(copylines,0,"copylines"),
@@ -55,40 +55,22 @@ static struct option options[] = {
 
 char boundary[COOKIE];
 
-substdio ssout;
-char outbuf[16];
-
-unsigned long when;
-const char *workdir;
-stralloc fn = {0};
-stralloc bdname = {0};
-stralloc fnlasth = {0};
-stralloc fnlastd = {0};
-stralloc lasth = {0};
-stralloc lastd = {0};
-struct stat st;
+static unsigned long when;
+static const char *workdir;
+static stralloc fn = {0};
+static stralloc bdname = {0};
+static stralloc fnlasth = {0};
+static stralloc fnlastd = {0};
+static stralloc lasth = {0};
+static stralloc lastd = {0};
 
 static void die_read(void) { strerr_die2sys(111,FATAL,MSG1(ERR_READ,fn.s)); }
 
-void makedir(const char *s)
-{
-  if (mkdir(s,0755) == -1)
-    if (errno != error_exist)
-      strerr_die2sys(111,FATAL,MSG1(ERR_CREATE,s));
-}
-
-char inbuf[1024];
-substdio ssin;
-char textbuf[1024];
-substdio sstext;
-
-stralloc addr = {0};
-char strnum[FMT_ULONG];
-char hash[COOKIE];
-stralloc fnhash = {0};
+static stralloc addr = {0};
+static stralloc fnhash = {0};
 stralloc quoted = {0};
 stralloc line = {0};
-stralloc qline = {0};
+static stralloc qline;
 
 struct qmail qq;
 
@@ -112,6 +94,12 @@ static void doit(int flagdig, int flagw)
   int match;
   int fdhash;
   const char *err;
+  char strnum[FMT_ULONG];
+  char textbuf[1024];
+  substdio sstext;
+  char inbuf[1024];
+  substdio ssin;
+  char hash[COOKIE];
 
   fd = open_read(fn.s);
   if (fd == -1) die_read();
@@ -241,9 +229,12 @@ static void dodir(int flagdig)
   direntry *d, *ds;
   unsigned long bouncedate;
   unsigned long ld;
-  unsigned long ddir,dfile;
-  int fdlock,fd;
+  int fd;
   char ch;
+  char strnum[FMT_ULONG];
+  substdio ssout;
+  char outbuf[16];
+  struct stat st;
 
   workdir = flagdig ? "digest" : ".";
 
@@ -266,13 +257,10 @@ static void dodir(int flagdig)
   if (flagdig)
     if (!stralloc_cats(&outlocal,"-digest")) die_nomem();
 
-  ddir = when / 10000;
-  dfile = when - 10000 * ddir;
-
   if (!stralloc_copys(&line,workdir)) die_nomem();
   if (!stralloc_cats(&line,"/lockbounce")) die_nomem();
   if (!stralloc_0(&line)) die_nomem();
-  fdlock = lockfile(line.s);
+  lockfile(line.s);
 
   if (!stralloc_copys(&line,workdir)) die_nomem();
   if (!stralloc_cats(&line,"/bounce/d")) die_nomem();
@@ -385,7 +373,7 @@ static void dodir(int flagdig)
       if (str_equal(d->d_name,".")) continue;
       if (str_equal(d->d_name,"..")) continue;
       if (!stralloc_copys(&fn,line.s)) die_nomem();
-      if (!stralloc_append(&fn,"/")) die_nomem();
+      if (!stralloc_append(&fn,'/')) die_nomem();
       if (!stralloc_cats(&fn,d->d_name)) die_nomem();
       if (!stralloc_0(&fn)) die_nomem();
       if (stat(fn.s,&st) == -1) {
@@ -415,6 +403,7 @@ static void dodir(int flagdig)
   closesub();
 }
 
+
 int main(int argc,char **argv)
 {
   (void) umask(022);
@@ -424,12 +413,12 @@ int main(int argc,char **argv)
   bouncetimeout *= 3600L * 24L;
   if (nowarn)
     _exit(0);
-  if (flagdig < 0) {
+  if (digopt < 0) {
     dodir(0);
     if (getconf_isset("digest"))
       dodir(1);
   }
   else
-    dodir(flagdig);
+    dodir(digopt);
   _exit(0);
 }
