@@ -8,6 +8,13 @@ static int parse(struct option *o,const char *arg)
   (void)arg;
 }
 
+static int counter(struct option *o,const char *arg)
+{
+  *o->var.flag += o->value.flag;
+  return 1;
+  (void)arg;
+}
+
 static void fetch(struct option *o)
 {
   *o->var.flag = !!getconf_isset(o->filename) ^ !o->value.flag;
@@ -18,3 +25,9 @@ const struct option_type opt_flag = {
   parse,
   fetch
 };
+
+const struct option_type opt_counter = {
+  0,
+  counter,
+  fetch
+};
