@@ -13,12 +13,12 @@ extern struct qmail qq;
 extern char flagcd;
 extern char boundary[HASHLEN];
 extern stralloc line;
-extern char strnum[FMT_ULONG];
 extern stralloc outhost;
 
 void hdr_datemsgid(unsigned long when)
 {
   char date[DATE822FMT];
+  char strnum[FMT_ULONG];
   struct datetime dt;
   qmail_puts(&qq,"Date: ");
   datetime_tai(&dt,when);
@@ -26,7 +26,7 @@ void hdr_datemsgid(unsigned long when)
   qmail_puts(&qq,"Message-ID: <");
   if (!stralloc_copyb(&line,strnum,fmt_ulong(strnum,(unsigned long)when)))
     die_nomem();
-  if (!stralloc_append(&line,".")) die_nomem();
+  if (!stralloc_append(&line,'.')) die_nomem();
   if (!stralloc_catb(&line,strnum,
 		     fmt_ulong(strnum,(unsigned long) getpid()))) die_nomem();
   if (!stralloc_cats(&line,".ezmlm@")) die_nomem();
