@@ -37,8 +37,6 @@ static stralloc dummyind = {0};
 static substdio ssindex;
 static char indexbuf[1024];
 
-static char strnum[FMT_ULONG];
-
 struct stat st;
 			/* if no data, these may be the entire table, so */
 			/* need to be static */
@@ -113,7 +111,7 @@ static void init_dummy(void)
   for (i = 0; i< HASHLEN; i++)
     dummyind.s[i] = 'a';
   dummyind.len = HASHLEN;
-  if (!stralloc_append(&dummyind," ")) die_nomem();
+  if (!stralloc_append(&dummyind,' ')) die_nomem();
 }
 
 void idx_mkthreads(msgentry **pmsgtable,	/* table of message<->subject */
@@ -149,7 +147,6 @@ void idx_mkthreads(msgentry **pmsgtable,	/* table of message<->subject */
   unsigned int authlen = 0;
   unsigned int pos = 0;
   unsigned int posa;
-  unsigned long submax;		/* max subject num in subtable */
   subentry *psubnext;		/* points to next entry in subtable */
   subentry *psubt;		/* points to entry in subtable */
   authentry *pauthnext;		/* points to next entry in authtable */
@@ -166,6 +163,7 @@ void idx_mkthreads(msgentry **pmsgtable,	/* table of message<->subject */
   unsigned int lastdate = 0;
   unsigned int thisdate;
   msgentry *x, *y;
+  char strnum[FMT_ULONG];
 
 				/* a few unnecessary sanity checks */
   if (msg_to > msg_latest)
@@ -198,7 +196,6 @@ void idx_mkthreads(msgentry **pmsgtable,	/* table of message<->subject */
 
   idxlatest = msg_latest / 100;
   idxto = msg_to / 100;
-  submax = 0;
   psubnext = *psubtable;	/* dummy node to get tree going. Basically, */
   psubt = &sdummy;		/* assure that subject > psubt-sub and that */
   init_dummy();			/* below ok unless HASHLEN > 40 */
@@ -305,8 +302,8 @@ void idx_mkthreads(msgentry **pmsgtable,	/* table of message<->subject */
       pmsgt->date = lastdate;
       if (hasauth) {
 	pos = 0;
-	while (authline.s[pos] && authline.s[pos] != ' ') pos++;
-	if (authline.s[++pos]) {
+	while (pos < authline.len && authline.s[pos] != ' ') pos++;
+	if (++pos < authline.len) {
 	  thisdate = date2yyyymm(authline.s + pos);
 	  if (thisdate) pmsgt->date = thisdate;
 	  if (pmsgt->date > lastdate) {
@@ -410,6 +407,7 @@ void idx_mkthread(msgentry **pmsgtable,		/* pointer to table of message<->subjec
   int match;
   msgentry *pmsgt;
   msgentry *x,*y;
+  char strnum[FMT_ULONG];
 
   if ((ulmrange = msg_to - msg_from +1) <= 0)
     strerr_die2x(100,FATAL,"Program error: bad range in idx_mkthreads");
@@ -529,7 +527,7 @@ void idx_mkthread(msgentry **pmsgtable,		/* pointer to table of message<->subjec
 	  psubt->lastmsg = msg;
           pmsgt->subnum = 1;
           if (flagauth) {
-	    if (*authline.s)
+	    if (authline.len > 0)
 	      pmsgt->date = date2yyyymm(authline.s + 1);
             pos = byte_chr(authline.s,authline.len,';');
 	    if (authline.len > pos + HASHLEN + 1 && authline.s[pos+1] != ' ') {
