@@ -13,15 +13,15 @@ void surfpcs_init(surfpcs *s,const uint32 k[32])
 }
 
 static const uint32 littleendian[8] = {
-  50462976, 117835012, 185207048, 252579084,
-  319951120, 387323156, 454695192, 522067228
+  0x03020100, 0x07060504, 0x0b0a0908, 0x0f0e0d0c,
+  0x13121110, 0x17161514, 0x1b1a1918, 0x1f1e1d1c
 } ;
 #define end ((unsigned char *) &littleendian)
 
 #define data ((unsigned char *) s->in)
 #define outdata ((unsigned char *) s->out)
 
-void surfpcs_add(surfpcs *s,const unsigned char *x,unsigned int n)
+void surfpcs_add(surfpcs *s,const char *x,unsigned int n)
 {
   int i;
   while (n--) {
@@ -39,11 +39,35 @@ void surfpcs_add(surfpcs *s,const unsigned char *x,unsigned int n)
   }
 }
 
+void surfpcs_addlc(surfpcs *s,const char *x,unsigned int n)
+/* modified from surfpcs_add by case-independence and skipping ' ' & '\t' */
+{
+  unsigned char ch;
+  int i;
+  while (n--) {
+    ch = *x++;
+    if (ch == ' ' || ch == '\t') continue;
+    if (ch >= 'A' && ch <= 'Z')
+      ch -= 'a' - 'A';
+    data[end[s->todo++]] = ch;
+    if (s->todo == 32) {
+      s->todo = 0;
+      if (!++s->in[8])
+        if (!++s->in[9])
+          if (!++s->in[10])
+            ++s->in[11];
+      surf(s->out,s->in,s->seed);
+      for (i = 0;i < 8;++i)
+	s->sum[i] += s->out[i];
+    }
+  }
+}
+
 void surfpcs_out(surfpcs *s,unsigned char h[32])
 {
   int i;
-  surfpcs_add(s,(const unsigned char*)".",1);
-  while (s->todo) surfpcs_add(s,(const unsigned char*)"",1);
+  surfpcs_add(s,".",1);
+  while (s->todo) surfpcs_add(s,"",1);
   for (i = 0;i < 8;++i) s->in[i] = s->sum[i];
   for (;i < 12;++i) s->in[i] = 0;
   surf(s->out,s->in,s->seed);
